@@ -54,6 +54,7 @@
 #define NETDATA_CHART_PRIO_SYSTEM_IPC_SHARED_MEM_SIZE  1206
 #define NETDATA_CHART_PRIO_SYSTEM_IPC_SHARED_MEM_CALLS 1207
 #define NETDATA_CHART_PRIO_SYSTEM_PACKETS              7001 // freebsd only
+#define NETDATA_CHART_PRIO_WINDOWS_THREADS             8001 // Windows only
 
 
 // CPU per core
@@ -286,6 +287,7 @@
 #define NETDATA_CHART_PRIO_IPV4_BCAST_PACKETS         5105
 #define NETDATA_CHART_PRIO_IPV4_MCAST                 5150
 #define NETDATA_CHART_PRIO_IPV4_MCAST_PACKETS         5155
+#define NETDATA_CHART_PRIO_IPV4_TCP_PACKETS           5170
 #define NETDATA_CHART_PRIO_IPV4_TCP_SOCKETS           5180
 #define NETDATA_CHART_PRIO_IPV4_TCP_SOCKETS_MEM       5185
 #define NETDATA_CHART_PRIO_IPV4_ICMP_PACKETS          5200
@@ -311,7 +313,9 @@
 #define NETDATA_CHART_PRIO_IPV6_BCAST                 6050
 #define NETDATA_CHART_PRIO_IPV6_MCAST                 6100
 #define NETDATA_CHART_PRIO_IPV6_MCAST_PACKETS         6105
+#define NETDATA_CHART_PRIO_IPV6_TCP_PACKETS           6130
 #define NETDATA_CHART_PRIO_IPV6_TCP_SOCKETS           6140
+#define NETDATA_CHART_PRIO_IPV6_ICMP_PACKETS          6145
 #define NETDATA_CHART_PRIO_IPV6_ICMP                  6150
 #define NETDATA_CHART_PRIO_IPV6_ICMP_REDIR            6155
 #define NETDATA_CHART_PRIO_IPV6_ICMP_ERRORS           6160
@@ -377,10 +381,11 @@
 
 // Linux Power Supply
 
-#define NETDATA_CHART_PRIO_POWER_SUPPLY_CAPACITY      9500 // 4 charts per power supply
-#define NETDATA_CHART_PRIO_POWER_SUPPLY_CHARGE        9501
-#define NETDATA_CHART_PRIO_POWER_SUPPLY_ENERGY        9502
-#define NETDATA_CHART_PRIO_POWER_SUPPLY_VOLTAGE       9503
+#define NETDATA_CHART_PRIO_POWER_SUPPLY_CAPACITY      9500 // 5 charts per power supply
+#define NETDATA_CHART_PRIO_POWER_SUPPLY_POWER         9501
+#define NETDATA_CHART_PRIO_POWER_SUPPLY_CHARGE        9502
+#define NETDATA_CHART_PRIO_POWER_SUPPLY_ENERGY        9503
+#define NETDATA_CHART_PRIO_POWER_SUPPLY_VOLTAGE       9504
 
 // Wireless
 
