@@ -334,7 +334,7 @@ static void ebpf_obsolete_cachestat_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_CACHESTAT_HIT_RATIO_CHART,
                               "Hit ratio",
-                              EBPF_COMMON_DIMENSION_PERCENTAGE,
+                              EBPF_COMMON_UNITS_PERCENTAGE,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_CACHESTAT_HIT_RATIO_CONTEXT,
@@ -345,7 +345,7 @@ static void ebpf_obsolete_cachestat_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_CACHESTAT_DIRTY_CHART,
                               "Number of dirty pages",
-                              EBPF_CACHESTAT_DIMENSION_PAGE,
+                              EBPF_CACHESTAT_UNITS_PAGE,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_CACHESTAT_MODIFIED_CACHE_CONTEXT,
@@ -356,7 +356,7 @@ static void ebpf_obsolete_cachestat_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_CACHESTAT_HIT_CHART,
                               "Number of accessed files",
-                              EBPF_CACHESTAT_DIMENSION_HITS,
+                              EBPF_CACHESTAT_UNITS_HITS,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_CACHESTAT_HIT_FILE_CONTEXT,
@@ -367,7 +367,7 @@ static void ebpf_obsolete_cachestat_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_CACHESTAT_MISSES_CHART,
                               "Files out of page cache",
-                              EBPF_CACHESTAT_DIMENSION_MISSES,
+                              EBPF_CACHESTAT_UNITS_MISSES,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_CACHESTAT_MISS_FILES_CONTEXT,
@@ -411,10 +411,10 @@ static void ebpf_obsolete_cachestat_global(ebpf_module_t *em)
                               NETDATA_CACHESTAT_HIT_RATIO_CHART,
                               "",
                               "Hit ratio",
-                              EBPF_COMMON_DIMENSION_PERCENTAGE,
+                              EBPF_COMMON_UNITS_PERCENTAGE,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_MEM_CACHESTAT_HIT_RATIO_CONTEXT,
                               21100,
                               em->update_every);
 
@@ -422,10 +422,10 @@ static void ebpf_obsolete_cachestat_global(ebpf_module_t *em)
                               NETDATA_CACHESTAT_DIRTY_CHART,
                               "",
                               "Number of dirty pages",
-                              EBPF_CACHESTAT_DIMENSION_PAGE,
+                              EBPF_CACHESTAT_UNITS_PAGE,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_MEM_CACHESTAT_MODIFIED_CACHE_CONTEXT,
                               21101,
                               em->update_every);
 
@@ -433,10 +433,10 @@ static void ebpf_obsolete_cachestat_global(ebpf_module_t *em)
                               NETDATA_CACHESTAT_HIT_CHART,
                               "",
                               "Number of accessed files",
-                              EBPF_CACHESTAT_DIMENSION_HITS,
+                              EBPF_CACHESTAT_UNITS_HITS,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_MEM_CACHESTAT_HIT_FILES_CONTEXT,
                               21102,
                               em->update_every);
 
@@ -444,10 +444,10 @@ static void ebpf_obsolete_cachestat_global(ebpf_module_t *em)
                               NETDATA_CACHESTAT_MISSES_CHART,
                               "",
                               "Files out of page cache",
-                              EBPF_CACHESTAT_DIMENSION_MISSES,
+                              EBPF_CACHESTAT_UNITS_MISSES,
                               NETDATA_CACHESTAT_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_MEM_CACHESTAT_MISS_FILES_CONTEXT,
                               21103,
                               em->update_every);
 }
@@ -472,7 +472,7 @@ void ebpf_obsolete_cachestat_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_cachestat_hit_ratio",
                                   "Hit ratio",
-                                  EBPF_COMMON_DIMENSION_PERCENTAGE,
+                                  EBPF_COMMON_UNITS_PERCENTAGE,
                                   NETDATA_CACHESTAT_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_LINE,
                                   "app.ebpf_cachestat_hit_ratio",
@@ -483,7 +483,7 @@ void ebpf_obsolete_cachestat_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_cachestat_dirty_pages",
                                   "Number of dirty pages",
-                                  EBPF_CACHESTAT_DIMENSION_PAGE,
+                                  EBPF_CACHESTAT_UNITS_PAGE,
                                   NETDATA_CACHESTAT_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_cachestat_dirty_pages",
@@ -494,7 +494,7 @@ void ebpf_obsolete_cachestat_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_cachestat_access",
                                   "Number of accessed files",
-                                  EBPF_CACHESTAT_DIMENSION_HITS,
+                                  EBPF_CACHESTAT_UNITS_HITS,
                                   NETDATA_CACHESTAT_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_cachestat_access",
@@ -505,7 +505,7 @@ void ebpf_obsolete_cachestat_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_cachestat_misses",
                                   "Files out of page cache",
-                                  EBPF_CACHESTAT_DIMENSION_MISSES,
+                                  EBPF_CACHESTAT_UNITS_MISSES,
                                   NETDATA_CACHESTAT_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_cachestat_misses",
@@ -523,12 +523,13 @@ void ebpf_obsolete_cachestat_apps_charts(struct ebpf_module *em)
  *
  * @param ptr thread data.
  */
-static void ebpf_cachestat_exit(void *ptr)
+static void ebpf_cachestat_exit(void *pptr)
 {
-    ebpf_module_t *em = (ebpf_module_t *)ptr;
+    ebpf_module_t *em = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!em) return;
 
     if (ebpf_read_cachestat.thread)
-        netdata_thread_cancel(*ebpf_read_cachestat.thread);
+        nd_thread_signal_cancel(ebpf_read_cachestat.thread);
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -840,13 +841,11 @@ void *ebpf_read_cachestat_thread(void *ptr)
     uint32_t lifetime = em->lifetime;
     uint32_t running_time = 0;
     usec_t period = update_every * USEC_PER_SEC;
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, period);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
-        netdata_thread_disable_cancelability();
-
         pthread_mutex_lock(&collect_data_mutex);
         ebpf_read_cachestat_apps_table(maps_per_core, max_period);
         ebpf_resume_apps_data();
@@ -862,7 +861,6 @@ void *ebpf_read_cachestat_thread(void *ptr)
 
         em->running_time = running_time;
         pthread_mutex_unlock(&ebpf_exit_cleanup);
-        netdata_thread_enable_cancelability();
     }
 
     return NULL;
@@ -888,14 +886,14 @@ void ebpf_cachestat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_cachestat_hit_ratio",
                              "Hit ratio",
-                             EBPF_COMMON_DIMENSION_PERCENTAGE,
+                             EBPF_COMMON_UNITS_PERCENTAGE,
                              NETDATA_CACHESTAT_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_LINE,
                              "app.ebpf_cachestat_hit_ratio",
                              20260,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_CACHESTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION ratio '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -904,14 +902,14 @@ void ebpf_cachestat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_cachestat_dirty_pages",
                              "Number of dirty pages",
-                             EBPF_CACHESTAT_DIMENSION_PAGE,
+                             EBPF_CACHESTAT_UNITS_PAGE,
                              NETDATA_CACHESTAT_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_LINE,
                              "app.ebpf_cachestat_dirty_pages",
                              20261,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_CACHESTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION pages '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -919,14 +917,14 @@ void ebpf_cachestat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_cachestat_access",
                              "Number of accessed files",
-                             EBPF_CACHESTAT_DIMENSION_HITS,
+                             EBPF_CACHESTAT_UNITS_HITS,
                              NETDATA_CACHESTAT_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_cachestat_access",
                              20262,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_CACHESTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION hits '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -934,14 +932,14 @@ void ebpf_cachestat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_cachestat_misses",
                              "Files out of page cache",
-                             EBPF_CACHESTAT_DIMENSION_MISSES,
+                             EBPF_CACHESTAT_UNITS_MISSES,
                              NETDATA_CACHESTAT_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_cachestat_misses",
                              20263,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_CACHESTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION misses '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
         w->charts_created |= 1<<EBPF_MODULE_CACHESTAT_IDX;
@@ -1117,7 +1115,7 @@ static void ebpf_create_systemd_cachestat_charts(int update_every)
 {
     static ebpf_systemd_args_t data_hit_ratio = {
         .title = "Hit ratio",
-        .units = EBPF_COMMON_DIMENSION_PERCENTAGE,
+        .units = EBPF_COMMON_UNITS_PERCENTAGE,
         .family = NETDATA_CACHESTAT_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21100,
@@ -1131,7 +1129,7 @@ static void ebpf_create_systemd_cachestat_charts(int update_every)
 
     static ebpf_systemd_args_t data_dirty = {
         .title = "Number of dirty pages",
-        .units = EBPF_CACHESTAT_DIMENSION_PAGE,
+        .units = EBPF_CACHESTAT_UNITS_PAGE,
         .family = NETDATA_CACHESTAT_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21101,
@@ -1144,8 +1142,8 @@ static void ebpf_create_systemd_cachestat_charts(int update_every)
     };
 
     static ebpf_systemd_args_t data_hit = {
-        .title = "Number of accessed pages",
-        .units = EBPF_CACHESTAT_DIMENSION_HITS,
+        .title = "Number of accessed files",
+        .units = EBPF_CACHESTAT_UNITS_HITS,
         .family = NETDATA_CACHESTAT_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21102,
@@ -1159,7 +1157,7 @@ static void ebpf_create_systemd_cachestat_charts(int update_every)
 
     static ebpf_systemd_args_t data_miss = {
         .title = "Files out of page cache",
-        .units = EBPF_CACHESTAT_DIMENSION_MISSES,
+        .units = EBPF_CACHESTAT_UNITS_MISSES,
         .family = NETDATA_CACHESTAT_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21103,
@@ -1259,40 +1257,49 @@ static void ebpf_send_specific_cachestat_data(char *type, netdata_publish_caches
  */
 static void ebpf_create_specific_cachestat_charts(char *type, int update_every)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_CACHESTAT_HIT_RATIO_CHART,
                       "Hit ratio",
-                      EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
+                      EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
                       NETDATA_CGROUP_CACHESTAT_HIT_RATIO_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5200,
                       ebpf_create_global_dimension,
                       cachestat_counter_publish_aggregated, 1, update_every, NETDATA_EBPF_MODULE_NAME_CACHESTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_CACHESTAT_DIRTY_CHART,
                       "Number of dirty pages",
-                      EBPF_CACHESTAT_DIMENSION_PAGE, NETDATA_CACHESTAT_SUBMENU,
+                      EBPF_CACHESTAT_UNITS_PAGE, NETDATA_CACHESTAT_SUBMENU,
                       NETDATA_CGROUP_CACHESTAT_MODIFIED_CACHE_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5201,
                       ebpf_create_global_dimension,
                       &cachestat_counter_publish_aggregated[NETDATA_CACHESTAT_IDX_DIRTY], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_CACHESTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_CACHESTAT_HIT_CHART,
                       "Number of accessed files",
-                      EBPF_CACHESTAT_DIMENSION_HITS, NETDATA_CACHESTAT_SUBMENU,
+                      EBPF_CACHESTAT_UNITS_HITS, NETDATA_CACHESTAT_SUBMENU,
                       NETDATA_CGROUP_CACHESTAT_HIT_FILES_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5202,
                       ebpf_create_global_dimension,
                       &cachestat_counter_publish_aggregated[NETDATA_CACHESTAT_IDX_HIT], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_CACHESTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_CACHESTAT_MISSES_CHART,
                       "Files out of page cache",
-                      EBPF_CACHESTAT_DIMENSION_MISSES, NETDATA_CACHESTAT_SUBMENU,
+                      EBPF_CACHESTAT_UNITS_MISSES, NETDATA_CACHESTAT_SUBMENU,
                       NETDATA_CGROUP_CACHESTAT_MISS_FILES_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5203,
                       ebpf_create_global_dimension,
                       &cachestat_counter_publish_aggregated[NETDATA_CACHESTAT_IDX_MISS], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_CACHESTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 }
 
 /**
@@ -1307,31 +1314,31 @@ static void ebpf_obsolete_specific_cachestat_charts(char *type, int update_every
 {
     ebpf_write_chart_obsolete(type, NETDATA_CACHESTAT_HIT_RATIO_CHART,
                               "",
-                      "Hit ratio",
-                      EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
-                      NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_HIT_RATIO_CONTEXT,
-                      NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5200, update_every);
+                              "Hit ratio",
+                              EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
+                              NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_HIT_RATIO_CONTEXT,
+                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5200, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_CACHESTAT_DIRTY_CHART,
                               "",
-                      "Number of dirty pages",
-                      EBPF_CACHESTAT_DIMENSION_PAGE, NETDATA_CACHESTAT_SUBMENU,
-                      NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_MODIFIED_CACHE_CONTEXT,
-                      NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5201, update_every);
+                              "Number of dirty pages",
+                              EBPF_CACHESTAT_UNITS_PAGE, NETDATA_CACHESTAT_SUBMENU,
+                              NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_MODIFIED_CACHE_CONTEXT,
+                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5201, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_CACHESTAT_HIT_CHART,
                               "",
-                      "Number of accessed files",
-                      EBPF_CACHESTAT_DIMENSION_HITS, NETDATA_CACHESTAT_SUBMENU,
-                      NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_HIT_FILES_CONTEXT,
-                      NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5202, update_every);
+                              "Number of accessed files",
+                              EBPF_CACHESTAT_UNITS_HITS, NETDATA_CACHESTAT_SUBMENU,
+                              NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_HIT_FILES_CONTEXT,
+                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5202, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_CACHESTAT_MISSES_CHART,
                               "",
-                      "Files out of page cache",
-                      EBPF_CACHESTAT_DIMENSION_MISSES, NETDATA_CACHESTAT_SUBMENU,
-                      NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_MISS_FILES_CONTEXT,
-                      NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5203, update_every);
+                              "Files out of page cache",
+                              EBPF_CACHESTAT_UNITS_MISSES, NETDATA_CACHESTAT_SUBMENU,
+                              NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_CACHESTAT_MISS_FILES_CONTEXT,
+                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5203, update_every);
 }
 
 /**
@@ -1393,17 +1400,17 @@ static void cachestat_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, USEC_PER_SEC);
 
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
         counter = 0;
         netdata_apps_integration_flags_t apps = em->apps_charts;
         ebpf_cachestat_read_global_tables(stats, maps_per_core);
 
-        if (cgroups)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_update_cachestat_cgroup();
 
         pthread_mutex_lock(&lock);
@@ -1413,7 +1420,7 @@ static void cachestat_collector(ebpf_module_t *em)
         if (apps & NETDATA_EBPF_APPS_FLAG_CHART_CREATED)
             ebpf_cache_send_apps_data(apps_groups_root_target);
 
-        if (cgroups)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_cachestat_send_cgroup_data(update_every);
 
         pthread_mutex_unlock(&lock);
@@ -1446,8 +1453,8 @@ static void ebpf_create_memory_charts(ebpf_module_t *em)
 {
     ebpf_create_chart(NETDATA_EBPF_MEMORY_GROUP, NETDATA_CACHESTAT_HIT_RATIO_CHART,
                       "Hit ratio",
-                      EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
-                      NULL,
+                      EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_CACHESTAT_SUBMENU,
+                      NETDATA_MEM_CACHESTAT_HIT_RATIO_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21100,
                       ebpf_create_global_dimension,
@@ -1455,8 +1462,8 @@ static void ebpf_create_memory_charts(ebpf_module_t *em)
 
     ebpf_create_chart(NETDATA_EBPF_MEMORY_GROUP, NETDATA_CACHESTAT_DIRTY_CHART,
                       "Number of dirty pages",
-                      EBPF_CACHESTAT_DIMENSION_PAGE, NETDATA_CACHESTAT_SUBMENU,
-                      NULL,
+                      EBPF_CACHESTAT_UNITS_PAGE, NETDATA_CACHESTAT_SUBMENU,
+                      NETDATA_MEM_CACHESTAT_MODIFIED_CACHE_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21101,
                       ebpf_create_global_dimension,
@@ -1465,8 +1472,8 @@ static void ebpf_create_memory_charts(ebpf_module_t *em)
 
     ebpf_create_chart(NETDATA_EBPF_MEMORY_GROUP, NETDATA_CACHESTAT_HIT_CHART,
                       "Number of accessed files",
-                      EBPF_CACHESTAT_DIMENSION_HITS, NETDATA_CACHESTAT_SUBMENU,
-                      NULL,
+                      EBPF_CACHESTAT_UNITS_HITS, NETDATA_CACHESTAT_SUBMENU,
+                      NETDATA_MEM_CACHESTAT_HIT_FILES_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21102,
                       ebpf_create_global_dimension,
@@ -1475,8 +1482,8 @@ static void ebpf_create_memory_charts(ebpf_module_t *em)
 
     ebpf_create_chart(NETDATA_EBPF_MEMORY_GROUP, NETDATA_CACHESTAT_MISSES_CHART,
                       "Files out of page cache",
-                      EBPF_CACHESTAT_DIMENSION_MISSES, NETDATA_CACHESTAT_SUBMENU,
-                      NULL,
+                      EBPF_CACHESTAT_UNITS_MISSES, NETDATA_CACHESTAT_SUBMENU,
+                      NETDATA_MEM_CACHESTAT_MISS_FILES_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21103,
                       ebpf_create_global_dimension,
@@ -1584,9 +1591,10 @@ static int ebpf_cachestat_load_bpf(ebpf_module_t *em)
  */
 void *ebpf_cachestat_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_cachestat_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+
+    CLEANUP_FUNCTION_REGISTER(ebpf_cachestat_exit) cleanup_ptr = em;
+
     em->maps = cachestat_maps;
 
     ebpf_update_pid_table(&cachestat_maps[NETDATA_CACHESTAT_PID_STATS], em);
@@ -1619,18 +1627,16 @@ void *ebpf_cachestat_thread(void *ptr)
 
     pthread_mutex_unlock(&lock);
 
-    ebpf_read_cachestat.thread = mallocz(sizeof(netdata_thread_t));
-    netdata_thread_create(ebpf_read_cachestat.thread,
-                          ebpf_read_cachestat.name,
-                          NETDATA_THREAD_OPTION_DEFAULT,
-                          ebpf_read_cachestat_thread,
-                          em);
+    ebpf_read_cachestat.thread = nd_thread_create(
+        ebpf_read_cachestat.name,
+        NETDATA_THREAD_OPTION_DEFAULT,
+        ebpf_read_cachestat_thread,
+        em);
 
     cachestat_collector(em);
 
 endcachestat:
     ebpf_update_disabled_plugin_stats(em);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
