@@ -283,7 +283,7 @@ static void ebpf_obsolete_dc_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_DC_HIT_CHART,
                               "Percentage of files inside directory cache",
-                              EBPF_COMMON_DIMENSION_PERCENTAGE,
+                              EBPF_COMMON_UNITS_PERCENTAGE,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_DC_HIT_RATIO_CONTEXT,
@@ -294,7 +294,7 @@ static void ebpf_obsolete_dc_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_DC_REFERENCE_CHART,
                               "Count file access",
-                              EBPF_COMMON_DIMENSION_FILES,
+                              EBPF_COMMON_UNITS_FILES,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_DC_REFERENCE_CONTEXT,
@@ -305,7 +305,7 @@ static void ebpf_obsolete_dc_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_DC_REQUEST_NOT_CACHE_CHART,
                               "Files not present inside directory cache",
-                              EBPF_COMMON_DIMENSION_FILES,
+                              EBPF_COMMON_UNITS_FILES,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_DC_NOT_CACHE_CONTEXT,
@@ -316,7 +316,7 @@ static void ebpf_obsolete_dc_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_DC_REQUEST_NOT_FOUND_CHART,
                               "Files not found",
-                              EBPF_COMMON_DIMENSION_FILES,
+                              EBPF_COMMON_UNITS_FILES,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_SYSTEMD_DC_NOT_FOUND_CONTEXT,
@@ -367,7 +367,7 @@ void ebpf_obsolete_dc_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_dc_hit",
                                   "Percentage of files inside directory cache.",
-                                  EBPF_COMMON_DIMENSION_PERCENTAGE,
+                                  EBPF_COMMON_UNITS_PERCENTAGE,
                                   NETDATA_DIRECTORY_CACHE_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_LINE,
                                   "app.ebpf_dc_hit",
@@ -378,7 +378,7 @@ void ebpf_obsolete_dc_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_dc_reference",
                                   "Count file access.",
-                                  EBPF_COMMON_DIMENSION_FILES,
+                                  EBPF_COMMON_UNITS_FILES,
                                   NETDATA_DIRECTORY_CACHE_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_dc_reference",
@@ -389,7 +389,7 @@ void ebpf_obsolete_dc_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_not_cache",
                                   "Files not present inside directory cache.",
-                                  EBPF_COMMON_DIMENSION_FILES,
+                                  EBPF_COMMON_UNITS_FILES,
                                   NETDATA_DIRECTORY_CACHE_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_dc_not_cache",
@@ -400,7 +400,7 @@ void ebpf_obsolete_dc_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_not_found",
                                   "Files not found.",
-                                  EBPF_COMMON_DIMENSION_FILES,
+                                  EBPF_COMMON_UNITS_FILES,
                                   NETDATA_DIRECTORY_CACHE_SUBMENU,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_dc_not_found",
@@ -425,10 +425,10 @@ static void ebpf_obsolete_dc_global(ebpf_module_t *em)
                               NETDATA_DC_HIT_CHART,
                               "",
                               "Percentage of files inside directory cache",
-                              EBPF_COMMON_DIMENSION_PERCENTAGE,
+                              EBPF_COMMON_UNITS_PERCENTAGE,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_FS_DC_HIT_RATIO_CONTEXT,
                               21200,
                               em->update_every);
 
@@ -436,10 +436,10 @@ static void ebpf_obsolete_dc_global(ebpf_module_t *em)
                               NETDATA_DC_REFERENCE_CHART,
                               "",
                               "Variables used to calculate hit ratio.",
-                              EBPF_COMMON_DIMENSION_FILES,
+                              EBPF_COMMON_UNITS_FILES,
                               NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_FS_DC_REFERENCE_CONTEXT,
                               21201,
                               em->update_every);
 }
@@ -451,12 +451,13 @@ static void ebpf_obsolete_dc_global(ebpf_module_t *em)
  *
  * @param ptr thread data.
  */
-static void ebpf_dcstat_exit(void *ptr)
+static void ebpf_dcstat_exit(void *pptr)
 {
-    ebpf_module_t *em = (ebpf_module_t *)ptr;
+    ebpf_module_t *em = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!em) return;
 
     if (ebpf_read_dcstat.thread)
-        netdata_thread_cancel(*ebpf_read_dcstat.thread);
+        nd_thread_signal_cancel(ebpf_read_dcstat.thread);
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -641,13 +642,11 @@ void *ebpf_read_dcstat_thread(void *ptr)
     uint32_t running_time = 0;
     usec_t period = update_every * USEC_PER_SEC;
     int max_period = update_every * EBPF_CLEANUP_FACTOR;
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, period);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
-        netdata_thread_disable_cancelability();
-
         pthread_mutex_lock(&collect_data_mutex);
         ebpf_read_dc_apps_table(maps_per_core, max_period);
         ebpf_dc_resume_apps_data();
@@ -663,7 +662,6 @@ void *ebpf_read_dcstat_thread(void *ptr)
 
         em->running_time = running_time;
         pthread_mutex_unlock(&ebpf_exit_cleanup);
-        netdata_thread_enable_cancelability();
     }
 
     return NULL;
@@ -689,14 +687,14 @@ void ebpf_dcstat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_dc_hit",
                              "Percentage of files inside directory cache.",
-                             EBPF_COMMON_DIMENSION_PERCENTAGE,
+                             EBPF_COMMON_UNITS_PERCENTAGE,
                              NETDATA_DIRECTORY_CACHE_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_LINE,
                              "app.ebpf_dc_hit",
                              20265,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_DCSTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION ratio '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -704,14 +702,14 @@ void ebpf_dcstat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_dc_reference",
                              "Count file access.",
-                             EBPF_COMMON_DIMENSION_FILES,
+                             EBPF_COMMON_UNITS_FILES,
                              NETDATA_DIRECTORY_CACHE_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_dc_reference",
                              20266,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_DCSTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION files '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -719,14 +717,14 @@ void ebpf_dcstat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_not_cache",
                              "Files not present inside directory cache.",
-                             EBPF_COMMON_DIMENSION_FILES,
+                             EBPF_COMMON_UNITS_FILES,
                              NETDATA_DIRECTORY_CACHE_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_dc_not_cache",
                              20267,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_DCSTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION files '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -734,14 +732,14 @@ void ebpf_dcstat_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_not_found",
                              "Files not found.",
-                             EBPF_COMMON_DIMENSION_FILES,
+                             EBPF_COMMON_UNITS_FILES,
                              NETDATA_DIRECTORY_CACHE_SUBMENU,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_dc_not_found",
                              20268,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_DCSTAT);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION files '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX]);
 
@@ -910,38 +908,47 @@ static void dcstat_send_global(netdata_publish_dcstat_t *publish)
  */
 static void ebpf_create_specific_dc_charts(char *type, int update_every)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_DC_HIT_CHART, "Percentage of files inside directory cache",
-                      EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
                       NETDATA_CGROUP_DC_HIT_RATIO_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5700,
                       ebpf_create_global_dimension,
                       dcstat_counter_publish_aggregated, 1, update_every, NETDATA_EBPF_MODULE_NAME_DCSTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_DC_REFERENCE_CHART, "Count file access",
-                      EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                       NETDATA_CGROUP_DC_REFERENCE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5701,
                       ebpf_create_global_dimension,
                       &dcstat_counter_publish_aggregated[NETDATA_DCSTAT_IDX_REFERENCE], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_DCSTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_DC_REQUEST_NOT_CACHE_CHART,
                       "Files not present inside directory cache",
-                      EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                       NETDATA_CGROUP_DC_NOT_CACHE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5702,
                       ebpf_create_global_dimension,
                       &dcstat_counter_publish_aggregated[NETDATA_DCSTAT_IDX_SLOW], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_DCSTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_DC_REQUEST_NOT_FOUND_CHART,
                       "Files not found",
-                      EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                       NETDATA_CGROUP_DC_NOT_FOUND_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5703,
                       ebpf_create_global_dimension,
                       &dcstat_counter_publish_aggregated[NETDATA_DCSTAT_IDX_MISS], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_DCSTAT);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 }
 
 /**
@@ -957,28 +964,28 @@ static void ebpf_obsolete_specific_dc_charts(char *type, int update_every)
     ebpf_write_chart_obsolete(type, NETDATA_DC_HIT_CHART,
                               "",
                               "Percentage of files inside directory cache",
-                              EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                              EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_DC_HIT_RATIO_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5700, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_DC_REFERENCE_CHART,
                               "",
                               "Count file access",
-                              EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                              EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_DC_REFERENCE_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5701, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_DC_REQUEST_NOT_CACHE_CHART,
                               "",
                               "Files not present inside directory cache",
-                              EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                              EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_DC_NOT_CACHE_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5702, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_DC_REQUEST_NOT_FOUND_CHART,
                               "",
                               "Files not found",
-                              EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                              EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_DC_NOT_FOUND_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5703, update_every);
 }
@@ -1042,7 +1049,7 @@ static void ebpf_create_systemd_dc_charts(int update_every)
 {
     static ebpf_systemd_args_t data_dc_hit_ratio = {
         .title = "Percentage of files inside directory cache",
-        .units = EBPF_COMMON_DIMENSION_PERCENTAGE,
+        .units = EBPF_COMMON_UNITS_PERCENTAGE,
         .family = NETDATA_DIRECTORY_CACHE_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21200,
@@ -1056,7 +1063,7 @@ static void ebpf_create_systemd_dc_charts(int update_every)
 
     static ebpf_systemd_args_t data_dc_references = {
         .title = "Count file access",
-        .units = EBPF_COMMON_DIMENSION_FILES,
+        .units = EBPF_COMMON_UNITS_FILES,
         .family = NETDATA_DIRECTORY_CACHE_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21201,
@@ -1070,7 +1077,7 @@ static void ebpf_create_systemd_dc_charts(int update_every)
 
     static ebpf_systemd_args_t data_dc_not_cache = {
         .title = "Files not present inside directory cache",
-        .units = EBPF_COMMON_DIMENSION_FILES,
+        .units = EBPF_COMMON_UNITS_FILES,
         .family = NETDATA_DIRECTORY_CACHE_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21202,
@@ -1084,7 +1091,7 @@ static void ebpf_create_systemd_dc_charts(int update_every)
 
     static ebpf_systemd_args_t data_dc_not_found = {
         .title = "Files not found",
-        .units = EBPF_COMMON_DIMENSION_FILES,
+        .units = EBPF_COMMON_UNITS_FILES,
         .family = NETDATA_DIRECTORY_CACHE_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_LINE,
         .order = 21203,
@@ -1252,17 +1259,17 @@ static void dcstat_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, USEC_PER_SEC);
 
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
         counter = 0;
         netdata_apps_integration_flags_t apps = em->apps_charts;
         ebpf_dc_read_global_tables(stats, maps_per_core);
 
-        if (cgroups)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_update_dc_cgroup();
 
         pthread_mutex_lock(&lock);
@@ -1272,7 +1279,7 @@ static void dcstat_collector(ebpf_module_t *em)
         if (apps & NETDATA_EBPF_APPS_FLAG_CHART_CREATED)
             ebpf_dcache_send_apps_data(apps_groups_root_target);
 
-        if (cgroups)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_dc_send_cgroup_data(update_every);
 
         pthread_mutex_unlock(&lock);
@@ -1305,8 +1312,8 @@ static void ebpf_create_dc_global_charts(int update_every)
 {
     ebpf_create_chart(NETDATA_FILESYSTEM_FAMILY, NETDATA_DC_HIT_CHART,
                       "Percentage of files inside directory cache",
-                      EBPF_COMMON_DIMENSION_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
-                      NULL,
+                      EBPF_COMMON_UNITS_PERCENTAGE, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      NETDATA_FS_DC_HIT_RATIO_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21200,
                       ebpf_create_global_dimension,
@@ -1314,8 +1321,8 @@ static void ebpf_create_dc_global_charts(int update_every)
 
     ebpf_create_chart(NETDATA_FILESYSTEM_FAMILY, NETDATA_DC_REFERENCE_CHART,
                       "Variables used to calculate hit ratio.",
-                      EBPF_COMMON_DIMENSION_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
-                      NULL,
+                      EBPF_COMMON_UNITS_FILES, NETDATA_DIRECTORY_CACHE_SUBMENU,
+                      NETDATA_FS_DC_REFERENCE_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21201,
                       ebpf_create_global_dimension,
@@ -1394,9 +1401,9 @@ static int ebpf_dcstat_load_bpf(ebpf_module_t *em)
  */
 void *ebpf_dcstat_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_dcstat_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+    CLEANUP_FUNCTION_REGISTER(ebpf_dcstat_exit) cleanup_ptr = em;
+
     em->maps = dcstat_maps;
 
     ebpf_update_pid_table(&dcstat_maps[NETDATA_DCSTAT_PID_STATS], em);
@@ -1428,18 +1435,13 @@ void *ebpf_dcstat_thread(void *ptr)
 
     pthread_mutex_unlock(&lock);
 
-    ebpf_read_dcstat.thread = mallocz(sizeof(netdata_thread_t));
-    netdata_thread_create(ebpf_read_dcstat.thread,
-                          ebpf_read_dcstat.name,
-                          NETDATA_THREAD_OPTION_DEFAULT,
-                          ebpf_read_dcstat_thread,
-                          em);
+    ebpf_read_dcstat.thread = nd_thread_create(ebpf_read_dcstat.name, NETDATA_THREAD_OPTION_DEFAULT,
+                                               ebpf_read_dcstat_thread, em);
 
     dcstat_collector(em);
 
 enddcstat:
     ebpf_update_disabled_plugin_stats(em);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
