@@ -260,7 +260,7 @@ static void ebpf_update_process_cgroup()
 static void ebpf_process_status_chart(char *family, char *name, char *axis,
                                       char *web, char *algorithm, int order, int update_every)
 {
-    printf("CHART %s.%s '' 'Process not closed' '%s' '%s' '' line %d %d '' 'ebpf.plugin' 'process'\n",
+    printf("CHART %s.%s '' 'Process not closed' '%s' '%s' 'system.process_status' line %d %d '' 'ebpf.plugin' 'process'\n",
            family,
            name,
            axis,
@@ -284,9 +284,9 @@ static void ebpf_create_global_charts(ebpf_module_t *em)
     ebpf_create_chart(NETDATA_EBPF_SYSTEM_GROUP,
                       NETDATA_PROCESS_SYSCALL,
                       "Start process",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_PROCESS_GROUP,
-                      NULL,
+                      "system.process_thread",
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21002,
                       ebpf_create_global_dimension,
@@ -296,9 +296,9 @@ static void ebpf_create_global_charts(ebpf_module_t *em)
     ebpf_create_chart(NETDATA_EBPF_SYSTEM_GROUP,
                       NETDATA_EXIT_SYSCALL,
                       "Exit process",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_PROCESS_GROUP,
-                      NULL,
+                      "system.exit",
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       21003,
                       ebpf_create_global_dimension,
@@ -307,7 +307,7 @@ static void ebpf_create_global_charts(ebpf_module_t *em)
 
     ebpf_process_status_chart(NETDATA_EBPF_SYSTEM_GROUP,
                               NETDATA_PROCESS_STATUS_NAME,
-                              EBPF_COMMON_DIMENSION_DIFFERENCE,
+                              EBPF_COMMON_UNITS_CALLS,
                               NETDATA_PROCESS_GROUP,
                               ebpf_algorithms[NETDATA_EBPF_ABSOLUTE_IDX],
                               21004, em->update_every);
@@ -316,9 +316,9 @@ static void ebpf_create_global_charts(ebpf_module_t *em)
         ebpf_create_chart(NETDATA_EBPF_SYSTEM_GROUP,
                           NETDATA_PROCESS_ERROR_NAME,
                           "Fails to create process",
-                          EBPF_COMMON_DIMENSION_CALL,
+                          EBPF_COMMON_UNITS_CALLS_PER_SEC,
                           NETDATA_PROCESS_GROUP,
-                          NULL,
+                          "system.task_error",
                           NETDATA_EBPF_CHART_TYPE_LINE,
                           21005,
                           ebpf_create_global_dimension,
@@ -350,14 +350,14 @@ void ebpf_process_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_process_start",
                              "Process started.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_PROCESS_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_process_start",
                              20161,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_PROCESS);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -365,14 +365,14 @@ void ebpf_process_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_thread_start",
                              "Threads started.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_PROCESS_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_thread_start",
                              20162,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_PROCESS);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -380,14 +380,14 @@ void ebpf_process_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_task_exit",
                              "Tasks starts exit process.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_PROCESS_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_task_exit",
                              20163,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_PROCESS);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -395,14 +395,14 @@ void ebpf_process_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_task_released",
                              "Tasks released.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_PROCESS_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_task_released",
                              20164,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_PROCESS);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -411,14 +411,14 @@ void ebpf_process_create_apps_charts(struct ebpf_module *em, void *ptr)
                                  w->clean_name,
                                  "_ebpf_task_error",
                                  "Errors to create process or threads.",
-                                 EBPF_COMMON_DIMENSION_CALL,
+                                 EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                  NETDATA_PROCESS_GROUP,
                                  NETDATA_EBPF_CHART_TYPE_STACKED,
                                  "app.ebpf_task_error",
                                  20165,
                                  update_every,
                                  NETDATA_EBPF_MODULE_NAME_PROCESS);
-            ebpf_create_chart_labels("app_group", w->name, 1);
+            ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
             ebpf_commit_label();
             fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
         }
@@ -449,10 +449,10 @@ static void ebpf_obsolete_process_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_TASK_PROCESS,
                               "Process started",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_PROCESS_CREATE_CONTEXT,
                               20065,
                               em->update_every);
 
@@ -460,10 +460,10 @@ static void ebpf_obsolete_process_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_TASK_THREAD,
                               "Threads started",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_THREAD_CREATE_CONTEXT,
                               20066,
                               em->update_every);
 
@@ -471,10 +471,10 @@ static void ebpf_obsolete_process_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_TASK_CLOSE,
                               "Tasks starts exit process.",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_PROCESS_EXIT_CONTEXT,
                               20067,
                               em->update_every);
 
@@ -482,10 +482,10 @@ static void ebpf_obsolete_process_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_TASK_EXIT,
                               "Tasks closed",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_PROCESS_CLOSE_CONTEXT,
                               20068,
                               em->update_every);
 
@@ -494,10 +494,10 @@ static void ebpf_obsolete_process_services(ebpf_module_t *em, char *id)
                                   id,
                                   NETDATA_SYSCALL_APPS_TASK_ERROR,
                                   "Errors to create process or threads.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
-                                  NULL,
+                                  NETDATA_SYSTEMD_PROCESS_ERROR_CONTEXT,
                                   20069,
                                   em->update_every);
     }
@@ -545,7 +545,7 @@ void ebpf_obsolete_process_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_process_start",
                                   "Process started.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_process_start",
@@ -556,7 +556,7 @@ void ebpf_obsolete_process_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_thread_start",
                                   "Threads started.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_thread_start",
@@ -567,7 +567,7 @@ void ebpf_obsolete_process_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_task_exit",
                                   "Tasks starts exit process.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_task_exit",
@@ -578,7 +578,7 @@ void ebpf_obsolete_process_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_task_released",
                                   "Tasks released.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_task_released",
@@ -590,7 +590,7 @@ void ebpf_obsolete_process_apps_charts(struct ebpf_module *em)
                                       w->clean_name,
                                       "_ebpf_task_error",
                                       "Errors to create process or threads.",
-                                      EBPF_COMMON_DIMENSION_CALL,
+                                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                       NETDATA_PROCESS_GROUP,
                                       NETDATA_EBPF_CHART_TYPE_STACKED,
                                       "app.ebpf_task_error",
@@ -615,10 +615,10 @@ static void ebpf_obsolete_process_global(ebpf_module_t *em)
                               NETDATA_PROCESS_SYSCALL,
                               "",
                               "Start process",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              "system.process_thread",
                               21002,
                               em->update_every);
 
@@ -626,10 +626,10 @@ static void ebpf_obsolete_process_global(ebpf_module_t *em)
                               NETDATA_EXIT_SYSCALL,
                               "",
                               "Exit process",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              "system.exit",
                               21003,
                               em->update_every);
 
@@ -637,10 +637,10 @@ static void ebpf_obsolete_process_global(ebpf_module_t *em)
                               NETDATA_PROCESS_STATUS_NAME,
                               "",
                               "Process not closed",
-                              EBPF_COMMON_DIMENSION_DIFFERENCE,
+                              EBPF_COMMON_UNITS_CALLS,
                               NETDATA_PROCESS_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              "system.process_status",
                               21004,
                               em->update_every);
 
@@ -649,10 +649,10 @@ static void ebpf_obsolete_process_global(ebpf_module_t *em)
                                   NETDATA_PROCESS_ERROR_NAME,
                                   "",
                                   "Fails to create process",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_PROCESS_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_LINE,
-                                  NULL,
+                                  "system.task_error",
                                   21005,
                                   em->update_every);
     }
@@ -689,9 +689,10 @@ static void ebpf_process_disable_tracepoints()
  *
  * @param ptr thread data.
  */
-static void ebpf_process_exit(void *ptr)
+static void ebpf_process_exit(void *pptr)
 {
-    ebpf_module_t *em = (ebpf_module_t *)ptr;
+    ebpf_module_t *em = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!em) return;
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -820,45 +821,56 @@ static void ebpf_send_specific_process_data(char *type, ebpf_process_stat_t *val
  */
 static void ebpf_create_specific_process_charts(char *type, ebpf_module_t *em)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_TASK_PROCESS, "Process started",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP,
                       NETDATA_CGROUP_PROCESS_CREATE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5000,
                       ebpf_create_global_dimension, &process_publish_aggregated[NETDATA_KEY_PUBLISH_PROCESS_FORK],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_PROCESS);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_TASK_THREAD, "Threads started",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP,
                       NETDATA_CGROUP_THREAD_CREATE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5001,
                       ebpf_create_global_dimension,
                       &process_publish_aggregated[NETDATA_KEY_PUBLISH_PROCESS_CLONE],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_PROCESS);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_TASK_EXIT, "Tasks starts exit process.",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP,
                       NETDATA_CGROUP_PROCESS_EXIT_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5002,
                       ebpf_create_global_dimension,
                       &process_publish_aggregated[NETDATA_KEY_PUBLISH_PROCESS_EXIT],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_PROCESS);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_TASK_CLOSE, "Tasks closed",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP,
                       NETDATA_CGROUP_PROCESS_CLOSE_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5003,
                       ebpf_create_global_dimension,
                       &process_publish_aggregated[NETDATA_KEY_PUBLISH_PROCESS_RELEASE_TASK],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_PROCESS);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     if (em->mode < MODE_ENTRY) {
         ebpf_create_chart(type, NETDATA_SYSCALL_APPS_TASK_ERROR, "Errors to create process or threads.",
-                          EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP,
+                          EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP,
                           NETDATA_CGROUP_PROCESS_ERROR_CONTEXT,
                           NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5004,
                           ebpf_create_global_dimension,
                           &process_publish_aggregated[NETDATA_KEY_PUBLISH_PROCESS_EXIT],
                           1, em->update_every, NETDATA_EBPF_MODULE_NAME_PROCESS);
+        ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+        ebpf_commit_label();
     }
 }
 
@@ -873,28 +885,28 @@ static void ebpf_create_specific_process_charts(char *type, ebpf_module_t *em)
 static void ebpf_obsolete_specific_process_charts(char *type, ebpf_module_t *em)
 {
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_TASK_PROCESS, "", "Process started",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_CGROUP_PROCESS_CREATE_CONTEXT, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5000,
                               em->update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_TASK_THREAD, "", "Threads started",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_CGROUP_THREAD_CREATE_CONTEXT, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5001,
                               em->update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_TASK_EXIT, "","Tasks starts exit process.",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_CGROUP_PROCESS_EXIT_CONTEXT, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5002,
                               em->update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_TASK_CLOSE, "","Tasks closed",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_CGROUP_PROCESS_CLOSE_CONTEXT, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5003,
                               em->update_every);
 
     if (em->mode < MODE_ENTRY) {
         ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_TASK_ERROR, "","Errors to create process or threads.",
-                                  EBPF_COMMON_DIMENSION_CALL, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_PROCESS_GROUP, NETDATA_EBPF_CHART_TYPE_LINE,
                                   NETDATA_CGROUP_PROCESS_ERROR_CONTEXT, NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5004,
                                   em->update_every);
     }
@@ -911,7 +923,7 @@ static void ebpf_create_systemd_process_charts(ebpf_module_t *em)
 {
     static ebpf_systemd_args_t data_process = {
         .title = "Process started",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_PROCESS_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20065,
@@ -925,7 +937,7 @@ static void ebpf_create_systemd_process_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t data_thread = {
         .title = "Threads started",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_PROCESS_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20066,
@@ -939,7 +951,7 @@ static void ebpf_create_systemd_process_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t task_exit = {
         .title = "Tasks starts exit process.",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_PROCESS_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20067,
@@ -953,7 +965,7 @@ static void ebpf_create_systemd_process_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t task_closed = {
         .title = "Tasks closed",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_PROCESS_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20068,
@@ -967,7 +979,7 @@ static void ebpf_create_systemd_process_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t task_error = {
         .title = "Errors to create process or threads.",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_PROCESS_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20069,
@@ -1124,10 +1136,10 @@ static void process_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         usec_t dt = heartbeat_next(&hb, USEC_PER_SEC);
         (void)dt;
-        if (ebpf_plugin_exit)
+        if (ebpf_plugin_stop())
             break;
 
         if (++counter == update_every) {
@@ -1268,9 +1280,10 @@ static int ebpf_process_enable_tracepoints()
  */
 void *ebpf_process_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_process_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+
+    CLEANUP_FUNCTION_REGISTER(ebpf_process_exit) cleanup_ptr = em;
+
     em->maps = process_maps;
 
     pthread_mutex_lock(&ebpf_exit_cleanup);
@@ -1311,6 +1324,5 @@ void *ebpf_process_thread(void *ptr)
     ebpf_update_disabled_plugin_stats(em);
     pthread_mutex_unlock(&ebpf_exit_cleanup);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
