@@ -125,10 +125,10 @@ static void local_socket_to_json_array(BUFFER *wb, LOCAL_SOCKET *n, uint64_t pro
         }
         buffer_json_add_array_item_string(wb, n->network_viewer.remote_address_space);
 
-        uint16_t server_port;
-        const char *server_address;
-        const char *client_address_space;
-        const char *server_address_space;
+        uint16_t server_port = 0;
+        const char *server_address = NULL;
+        const char *client_address_space = NULL;
+        const char *server_address_space = NULL;
         switch (n->direction) {
             case SOCKET_DIRECTION_LISTEN:
             case SOCKET_DIRECTION_INBOUND:
@@ -739,7 +739,7 @@ close_and_send:
 
 int main(int argc __maybe_unused, char **argv __maybe_unused) {
     clocks_init();
-    netdata_thread_set_tag("NETWORK-VIEWER");
+    nd_thread_tag_set("NETWORK-VIEWER");
     nd_log_initialize_for_external_plugins("network-viewer.plugin");
 
     netdata_configured_host_prefix = getenv("NETDATA_HOST_PREFIX");
