@@ -534,7 +534,7 @@ static struct {
                 .category = BIC_DATABASE,
                 .type = BIT_BOOLEAN,
                 .analytics = "dbengine",
-                .print = "dbengine",
+                .print = "dbengine (compression)",
                 .json = "dbengine",
                 .value = NULL,
         },
@@ -1037,10 +1037,10 @@ static void build_info_set_status(BUILD_INFO_SLOT slot, bool status) {
 }
 
 __attribute__((constructor)) void initialize_build_info(void) {
-    build_info_set_value(BIB_PACKAGING_NETDATA_VERSION, program_version);
+    build_info_set_value(BIB_PACKAGING_NETDATA_VERSION, NETDATA_VERSION);
     build_info_set_value(BIB_PACKAGING_CONFIGURE_OPTIONS, CONFIGURE_COMMAND);
 
-#ifdef COMPILED_FOR_LINUX
+#ifdef OS_LINUX
     build_info_set_status(BIB_FEATURE_BUILT_FOR, true);
     build_info_set_value(BIB_FEATURE_BUILT_FOR, "Linux");
     build_info_set_status(BIB_PLUGIN_LINUX_CGROUPS, true);
@@ -1048,16 +1048,26 @@ __attribute__((constructor)) void initialize_build_info(void) {
     build_info_set_status(BIB_PLUGIN_LINUX_DISKSPACE, true);
     build_info_set_status(BIB_PLUGIN_LINUX_TC, true);
 #endif
-#ifdef COMPILED_FOR_FREEBSD
+#ifdef OS_FREEBSD
     build_info_set_status(BIB_FEATURE_BUILT_FOR, true);
     build_info_set_value(BIB_FEATURE_BUILT_FOR, "FreeBSD");
     build_info_set_status(BIB_PLUGIN_FREEBSD, true);
 #endif
-#ifdef COMPILED_FOR_MACOS
+#ifdef OS_MACOS
     build_info_set_status(BIB_FEATURE_BUILT_FOR, true);
     build_info_set_value(BIB_FEATURE_BUILT_FOR, "MacOS");
     build_info_set_status(BIB_PLUGIN_MACOS, true);
 #endif
+#ifdef OS_WINDOWS
+    build_info_set_status(BIB_FEATURE_BUILT_FOR, true);
+#if defined(__CYGWIN__) && defined(__MSYS__)
+    build_info_set_value(BIB_FEATURE_BUILT_FOR, "Windows (MSYS)");
+#elif defined(__CYGWIN__)
+    build_info_set_value(BIB_FEATURE_BUILT_FOR, "Windows (CYGWIN)");
+#else
+    build_info_set_value(BIB_FEATURE_BUILT_FOR, "Windows");
+#endif
+#endif
 
 #ifdef ENABLE_ACLK
     build_info_set_status(BIB_FEATURE_CLOUD, true);
@@ -1098,6 +1108,12 @@ __attribute__((constructor)) void initialize_build_info(void) {
 
 #ifdef ENABLE_DBENGINE
     build_info_set_status(BIB_DB_DBENGINE, true);
+#ifdef ENABLE_ZSTD
+    build_info_append_value(BIB_DB_DBENGINE, "zstd");
+#endif
+#ifdef ENABLE_LZ4
+    build_info_append_value(BIB_DB_DBENGINE, "lz4");
+#endif
 #endif
     build_info_set_status(BIB_DB_ALLOC, true);
     build_info_set_status(BIB_DB_RAM, true);
