@@ -47,6 +47,9 @@ static cmd_status_t cmd_ping_execute(char *args, char **message);
 static cmd_status_t cmd_aclk_state(char *args, char **message);
 static cmd_status_t cmd_version(char *args, char **message);
 static cmd_status_t cmd_dumpconfig(char *args, char **message);
+#ifdef ENABLE_ACLK
+static cmd_status_t cmd_remove_node(char *args, char **message);
+#endif
 
 static command_info_t command_info_array[] = {
         {"help", cmd_help_execute, CMD_TYPE_HIGH_PRIORITY},                  // show help menu
@@ -61,7 +64,10 @@ static command_info_t command_info_array[] = {
         {"ping", cmd_ping_execute, CMD_TYPE_ORTHOGONAL},
         {"aclk-state", cmd_aclk_state, CMD_TYPE_ORTHOGONAL},
         {"version", cmd_version, CMD_TYPE_ORTHOGONAL},
-        {"dumpconfig", cmd_dumpconfig, CMD_TYPE_ORTHOGONAL}
+        {"dumpconfig", cmd_dumpconfig, CMD_TYPE_ORTHOGONAL},
+#ifdef ENABLE_ACLK
+        {"remove-stale-node", cmd_remove_node, CMD_TYPE_ORTHOGONAL}
+#endif
 };
 
 /* Mutexes for commands of type CMD_TYPE_ORTHOGONAL */
@@ -129,6 +135,10 @@ static cmd_status_t cmd_help_execute(char *args, char **message)
              "    Returns current state of ACLK and Cloud connection. (optionally in json).\n"
              "dumpconfig\n"
              "    Returns the current netdata.conf on stdout.\n"
+#ifdef ENABLE_ACLK
+             "remove-stale-node node_id|machine_guid\n"
+             "    Unregisters and removes a node from the cloud.\n"
+#endif
              "version\n"
              "    Returns the netdata version.\n",
              MAX_COMMAND_LENGTH - 1);
@@ -202,6 +212,7 @@ static cmd_status_t cmd_reload_labels_execute(char *args, char **message)
     (void)args;
     netdata_log_info("COMMAND: reloading host labels.");
     reload_host_labels();
+    aclk_queue_node_info(localhost, 1);
 
     BUFFER *wb = buffer_create(10, NULL);
     rrdlabels_log_to_buffer(localhost->rrdlabels, wb);
@@ -308,7 +319,7 @@ static cmd_status_t cmd_version(char *args, char **message)
     (void)args;
 
     char version[MAX_COMMAND_LENGTH];
-    snprintfz(version, MAX_COMMAND_LENGTH -1, "%s %s", program_name, program_version);
+    snprintfz(version, MAX_COMMAND_LENGTH -1, "%s %s", program_name, NETDATA_VERSION);
 
     *message = strdupz(version);
 
@@ -326,6 +337,56 @@ static cmd_status_t cmd_dumpconfig(char *args, char **message)
     return CMD_STATUS_SUCCESS;
 }
 
+#ifdef ENABLE_ACLK
+static cmd_status_t cmd_remove_node(char *args, char **message)
+{
+    (void)args;
+
+    BUFFER *wb = buffer_create(1024, NULL);
+    if (strlen(args) == 0) {
+        buffer_sprintf(wb, "Please specify a machine or node UUID");
+        goto done;
+    }
+
+    RRDHOST *host = NULL;
+    host = rrdhost_find_by_guid(args);
+    if (!host)
+        host = find_host_by_node_id(args);
+
+    if (!host)
+        buffer_sprintf(wb, "Node with machine or node UUID \"%s\" not found", args);
+    else {
+
+        if (host == localhost) {
+            buffer_sprintf(wb, "You cannot unregister the parent node");
+            goto done;
+        }
+
+        if (rrdhost_is_online(host)) {
+            buffer_sprintf(wb, "Cannot unregister a live node");
+            goto done;
+        }
+
+        if (!rrdhost_option_check(host, RRDHOST_OPTION_EPHEMERAL_HOST)) {
+            rrdhost_option_set(host, RRDHOST_OPTION_EPHEMERAL_HOST);
+            sql_set_host_label(&host->host_uuid, "_is_ephemeral", "true");
+            aclk_host_state_update(host, 0, 0);
+            unregister_node(host->machine_guid);
+            freez(host->node_id);
+            host->node_id = NULL;
+            buffer_sprintf(wb, "Unregistering node with machine guid %s, hostname = %s", host->machine_guid, rrdhost_hostname(host));
+        }
+        else
+            buffer_sprintf(wb, "Node with machine guid %s, hostname = %s is already unregistered", host->machine_guid, rrdhost_hostname(host));
+    }
+
+done:
+    *message = strdupz(buffer_tostring(wb));
+    buffer_free(wb);
+    return CMD_STATUS_SUCCESS;
+}
+#endif
+
 static void cmd_lock_exclusive(unsigned index)
 {
     (void)index;
@@ -483,15 +544,15 @@ static void parse_commands(struct command_context *cmd_ctx)
     status = CMD_STATUS_FAILURE;
 
     /* Skip white-space characters */
-    for (pos = cmd_ctx->command_string ; isspace(*pos) && ('\0' != *pos) ; ++pos) ;
+    for (pos = cmd_ctx->command_string ; isspace((uint8_t)*pos) && ('\0' != *pos) ; ++pos) ;
     for (i = 0 ; i < CMD_TOTAL_COMMANDS ; ++i) {
         if (!strncmp(pos, command_info_array[i].cmd_str, strlen(command_info_array[i].cmd_str))) {
             if (CMD_EXIT == i) {
                 /* musl C does not like libuv workqueues calling exit() */
                 execute_command(CMD_EXIT, NULL, NULL);
             }
-            for (lstrip=pos + strlen(command_info_array[i].cmd_str); isspace(*lstrip) && ('\0' != *lstrip); ++lstrip) ;
-            for (rstrip=lstrip+strlen(lstrip)-1; rstrip>lstrip && isspace(*rstrip); *(rstrip--) = 0 ) ;
+            for (lstrip=pos + strlen(command_info_array[i].cmd_str); isspace((uint8_t)*lstrip) && ('\0' != *lstrip); ++lstrip) ;
+            for (rstrip=lstrip+strlen(lstrip)-1; rstrip>lstrip && isspace((uint8_t)*rstrip); *(rstrip--) = 0 ) ;
 
             cmd_ctx->work.data = cmd_ctx;
             cmd_ctx->idx = i;
@@ -596,8 +657,9 @@ static void async_cb(uv_async_t *handle)
     uv_stop(handle->loop);
 }
 
-static void command_thread(void *arg)
-{
+static void command_thread(void *arg) {
+    uv_thread_set_name_np("DAEMON_COMMAND");
+
     int ret;
     uv_fs_t req;
 
@@ -714,7 +776,6 @@ void commands_init(void)
     /* wait for worker thread to initialize */
     completion_wait_for(&completion);
     completion_destroy(&completion);
-    uv_thread_set_name_np(thread, "DAEMON_COMMAND");
 
     if (command_thread_error) {
         error = uv_thread_join(&thread);
