@@ -121,11 +121,7 @@ static int become_user(const char *username, int pid_fd) {
     gid_t *supplementary_groups = NULL;
     if(ngroups > 0) {
         supplementary_groups = mallocz(sizeof(gid_t) * ngroups);
-#ifdef __APPLE__
-        if(getgrouplist(username, gid, (int *)supplementary_groups, &ngroups) == -1) {
-#else
-        if(getgrouplist(username, gid, supplementary_groups, &ngroups) == -1) {
-#endif /* __APPLE__ */
+        if(os_getgrouplist(username, gid, supplementary_groups, &ngroups) == -1) {
             if(am_i_root)
                 netdata_log_error("Cannot get supplementary groups of user '%s'.", username);
 
@@ -149,20 +145,12 @@ static int become_user(const char *username, int pid_fd) {
     if(supplementary_groups)
         freez(supplementary_groups);
 
-#ifdef __APPLE__
-    if(setregid(gid, gid) != 0) {
-#else
-    if(setresgid(gid, gid, gid) != 0) {
-#endif /* __APPLE__ */
+    if(os_setresgid(gid, gid, gid) != 0) {
         netdata_log_error("Cannot switch to user's %s group (gid: %u).", username, gid);
         return -1;
     }
 
-#ifdef __APPLE__
-    if(setreuid(uid, uid) != 0) {
-#else
-    if(setresuid(uid, uid, uid) != 0) {
-#endif /* __APPLE__ */
+    if(os_setresuid(uid, uid, uid) != 0) {
         netdata_log_error("Cannot switch to user %s (uid: %u).", username, uid);
         return -1;
     }
@@ -218,7 +206,7 @@ static void oom_score_adj(void) {
 
     // check netdata.conf configuration
     s = config_get(CONFIG_SECTION_GLOBAL, "OOM score", s);
-    if(s && *s && (isdigit(*s) || *s == '-' || *s == '+'))
+    if(s && *s && (isdigit((uint8_t)*s) || *s == '-' || *s == '+'))
         wanted_score = atoll(s);
     else if(s && !strcmp(s, "keep")) {
         netdata_log_info("Out-Of-Memory (OOM) kept as-is (running with %d)", (int) old_score);
