@@ -3,17 +3,18 @@
 #define NETDATA_RRD_INTERNALS
 #include "rrd.h"
 
+#if RRD_STORAGE_TIERS != 5
+#error RRD_STORAGE_TIERS is not 5 - you need to update the grouping iterations per tier
+#endif
+
 static void rrdhost_streaming_sender_structures_init(RRDHOST *host);
 
 bool dbengine_enabled = false; // will become true if and when dbengine is initialized
 size_t storage_tiers = 3;
 bool use_direct_io = true;
-size_t storage_tiers_grouping_iterations[RRD_STORAGE_TIERS] = { 1, 60, 60, 60, 60 };
-RRD_BACKFILL storage_tiers_backfill[RRD_STORAGE_TIERS] = { RRD_BACKFILL_NEW, RRD_BACKFILL_NEW, RRD_BACKFILL_NEW, RRD_BACKFILL_NEW, RRD_BACKFILL_NEW };
-
-#if RRD_STORAGE_TIERS != 5
-#error RRD_STORAGE_TIERS is not 5 - you need to update the grouping iterations per tier
-#endif
+size_t storage_tiers_grouping_iterations[RRD_STORAGE_TIERS] = {1, 60, 60, 60, 60};
+size_t storage_tiers_collection_per_sec[RRD_STORAGE_TIERS] = {1, 60, 3600, 8 * 3600, 24 * 3600};
+double storage_tiers_retention_days[RRD_STORAGE_TIERS] = {14, 90, 2 * 365, 2 * 365, 2 * 365};
 
 size_t get_tier_grouping(size_t tier) {
     if(unlikely(tier >= storage_tiers)) tier = storage_tiers - 1;
@@ -33,24 +34,15 @@ time_t rrdset_free_obsolete_time_s = 3600;
 time_t rrdhost_free_orphan_time_s = 3600;
 time_t rrdhost_free_ephemeral_time_s = 86400;
 
-bool is_storage_engine_shared(STORAGE_INSTANCE *si __maybe_unused) {
-#ifdef ENABLE_DBENGINE
-    if(!rrdeng_is_legacy(si))
-        return true;
-#endif
-
-    return false;
-}
-
 RRDHOST *find_host_by_node_id(char *node_id) {
 
-    uuid_t node_uuid;
+    nd_uuid_t node_uuid;
     if (unlikely(!node_id || uuid_parse(node_id, node_uuid)))
         return NULL;
 
     RRDHOST *host, *ret = NULL;
     dfe_start_read(rrdhost_root_index, host) {
-        if (host->node_id && !(uuid_memcmp(host->node_id, &node_uuid))) {
+        if (host->node_id && uuid_eq(*host->node_id, node_uuid)) {
             ret = host;
             break;
         }
@@ -269,6 +261,73 @@ static void rrdhost_initialize_rrdpush_sender(RRDHOST *host,
         rrdhost_option_clear(host, RRDHOST_OPTION_SENDER_ENABLED);
 }
 
+#ifdef ENABLE_DBENGINE
+//
+//  true on success
+//
+static bool create_dbengine_directory(RRDHOST *host, const char *dbenginepath)
+{
+    int ret = mkdir(dbenginepath, 0775);
+    if (ret != 0 && errno != EEXIST) {
+        nd_log(NDLS_DAEMON, NDLP_CRIT, "Host '%s': cannot create directory '%s'", rrdhost_hostname(host), dbenginepath);
+        return false;
+    }
+    return true;
+}
+
+static RRDHOST *prepare_host_for_unittest(RRDHOST *host)
+{
+    char dbenginepath[FILENAME_MAX + 1];
+
+    if (host->cache_dir)
+        freez(host->cache_dir);
+
+    snprintfz(dbenginepath, FILENAME_MAX, "%s/%s", netdata_configured_cache_dir, host->machine_guid);
+    host->cache_dir = strdupz(dbenginepath);
+
+    int ret = 0;
+
+    bool initialized;
+    if ((initialized = create_dbengine_directory(host, dbenginepath))) {
+        snprintfz(dbenginepath, FILENAME_MAX, "%s/dbengine", host->cache_dir);
+
+        if ((initialized = create_dbengine_directory(host, dbenginepath))) {
+            host->db[0].mode = RRD_MEMORY_MODE_DBENGINE;
+            host->db[0].eng = storage_engine_get(host->db[0].mode);
+            host->db[0].tier_grouping = get_tier_grouping(0);
+
+            ret = rrdeng_init(
+                (struct rrdengine_instance **)&host->db[0].si,
+                dbenginepath,
+                default_rrdeng_disk_quota_mb,
+                0,
+                0); // may fail here for legacy dbengine initialization
+
+            initialized = (ret == 0);
+
+            if (initialized)
+                rrdeng_readiness_wait((struct rrdengine_instance *)host->db[0].si);
+        }
+    }
+
+    if (!initialized) {
+        nd_log(
+            NDLS_DAEMON,
+            NDLP_CRIT,
+            "Host '%s': cannot initialize host with machine guid '%s'. Failed to initialize DB engine at '%s'.",
+            rrdhost_hostname(host),
+            host->machine_guid,
+            host->cache_dir);
+
+        rrd_wrlock();
+        rrdhost_free___while_having_rrd_wrlock(host, true);
+        rrd_wrunlock();
+        return NULL;
+    }
+    return host;
+}
+#endif
+
 static RRDHOST *rrdhost_create(
         const char *hostname,
         const char *registry_hostname,
@@ -302,20 +361,20 @@ static RRDHOST *rrdhost_create(
         memory_mode = RRD_MEMORY_MODE_ALLOC;
     }
 
-#ifdef ENABLE_DBENGINE
-    int is_legacy = (memory_mode == RRD_MEMORY_MODE_DBENGINE) && is_legacy_child(guid);
-#else
-int is_legacy = 1;
-#endif
-
-    int is_in_multihost = (memory_mode == RRD_MEMORY_MODE_DBENGINE && !is_legacy);
     RRDHOST *host = callocz(1, sizeof(RRDHOST));
     __atomic_add_fetch(&netdata_buffers_statistics.rrdhost_allocations_size, sizeof(RRDHOST), __ATOMIC_RELAXED);
 
     strncpyz(host->machine_guid, guid, GUID_LEN + 1);
 
-    set_host_properties(host, (update_every > 0)?update_every:1, memory_mode, registry_hostname, os,
-                        timezone, abbrev_timezone, utc_offset,
+    set_host_properties(
+        host,
+        (update_every > 0) ? update_every : 1,
+        memory_mode,
+        registry_hostname,
+        os,
+        timezone,
+        abbrev_timezone,
+        utc_offset,
         prog_name,
         prog_version);
 
@@ -360,28 +419,8 @@ int is_legacy = 1;
 
     rrdset_index_init(host);
 
-    char filename[FILENAME_MAX + 1];
     if(is_localhost)
         host->cache_dir  = strdupz(netdata_configured_cache_dir);
-    else {
-        // this is not localhost - append our GUID to localhost path
-        if (is_in_multihost) { // don't append to cache dir in multihost
-            host->cache_dir  = strdupz(netdata_configured_cache_dir);
-        }
-        else {
-            snprintfz(filename, FILENAME_MAX, "%s/%s", netdata_configured_cache_dir, host->machine_guid);
-            host->cache_dir = strdupz(filename);
-        }
-
-        if(host->rrd_memory_mode == RRD_MEMORY_MODE_DBENGINE && is_legacy)
-        {
-            int r = mkdir(host->cache_dir, 0775);
-            if(r != 0 && errno != EEXIST)
-                nd_log(NDLS_DAEMON, NDLP_CRIT,
-                       "Host '%s': cannot create directory '%s'",
-                       rrdhost_hostname(host), host->cache_dir);
-        }
-    }
 
     // this is also needed for custom host variables - not only health
     if(!host->rrdvars)
@@ -396,45 +435,10 @@ int is_legacy = 1;
 
     if (host->rrd_memory_mode == RRD_MEMORY_MODE_DBENGINE) {
 #ifdef ENABLE_DBENGINE
-        char dbenginepath[FILENAME_MAX + 1];
-        int ret;
-
-        snprintfz(dbenginepath, FILENAME_MAX, "%s/dbengine", host->cache_dir);
-        ret = mkdir(dbenginepath, 0775);
-
-        if (ret != 0 && errno != EEXIST)
-            nd_log(NDLS_DAEMON, NDLP_CRIT,
-                   "Host '%s': cannot create directory '%s'",
-                   rrdhost_hostname(host), dbenginepath);
-        else
-            ret = 0; // succeed
-
-        if (is_legacy) {
-            // initialize legacy dbengine instance as needed
-
-            host->db[0].mode = RRD_MEMORY_MODE_DBENGINE;
-            host->db[0].eng = storage_engine_get(host->db[0].mode);
-            host->db[0].tier_grouping = get_tier_grouping(0);
-
-            ret = rrdeng_init(
-                (struct rrdengine_instance **)&host->db[0].si,
-                dbenginepath,
-                default_rrdeng_disk_quota_mb,
-                0); // may fail here for legacy dbengine initialization
-
-            if(ret == 0) {
-                rrdeng_readiness_wait((struct rrdengine_instance *)host->db[0].si);
-
-                // assign the rest of the shared storage instances to it
-                // to allow them collect its metrics too
-
-                for(size_t tier = 1; tier < storage_tiers ; tier++) {
-                    host->db[tier].mode = RRD_MEMORY_MODE_DBENGINE;
-                    host->db[tier].eng = storage_engine_get(host->db[tier].mode);
-                    host->db[tier].si = (STORAGE_INSTANCE *) multidb_ctx[tier];
-                    host->db[tier].tier_grouping = get_tier_grouping(tier);
-                }
-            }
+        if (unittest_running) {
+            host = prepare_host_for_unittest(host);
+            if (!host)
+                return NULL;
         }
         else {
             for(size_t tier = 0; tier < storage_tiers ; tier++) {
@@ -444,19 +448,6 @@ int is_legacy = 1;
                 host->db[tier].tier_grouping = get_tier_grouping(tier);
             }
         }
-
-        if (ret) { // check legacy or multihost initialization success
-            nd_log(NDLS_DAEMON, NDLP_CRIT,
-                   "Host '%s': cannot initialize host with machine guid '%s'. Failed to initialize DB engine at '%s'.",
-                   rrdhost_hostname(host), host->machine_guid, host->cache_dir);
-
-            rrd_wrlock();
-            rrdhost_free___while_having_rrd_wrlock(host, true);
-            rrd_unlock();
-
-            return NULL;
-        }
-
 #else
         fatal("RRD_MEMORY_MODE_DBENGINE is not supported in this platform.");
 #endif
@@ -503,7 +494,7 @@ int is_legacy = 1;
         if (!is_localhost)
             rrdhost_free___while_having_rrd_wrlock(host, true);
 
-        rrd_unlock();
+        rrd_wrunlock();
         return NULL;
     }
 
@@ -514,7 +505,7 @@ int is_legacy = 1;
     else
         DOUBLE_LINKED_LIST_APPEND_ITEM_UNSAFE(localhost, host, prev, next);
 
-    rrd_unlock();
+    rrd_wrunlock();
 
     // ------------------------------------------------------------------------
 
@@ -693,7 +684,7 @@ static void rrdhost_update(RRDHOST *host
         host->rrdpush_replication_step = rrdpush_replication_step;
 
         ml_host_new(host);
-        
+
         rrdhost_load_rrdcontext_data(host);
         nd_log(NDLS_DAEMON, NDLP_DEBUG,
                "Host %s is not in archived mode anymore",
@@ -743,7 +734,7 @@ RRDHOST *rrdhost_find_or_create(
         rrd_wrlock();
         rrdhost_free___while_having_rrd_wrlock(host, true);
         host = NULL;
-        rrd_unlock();
+        rrd_wrunlock();
     }
 
     if(!host) {
@@ -822,26 +813,65 @@ inline int rrdhost_should_be_removed(RRDHOST *host, RRDHOST *protected_host, tim
 
 #ifdef ENABLE_DBENGINE
 struct dbengine_initialization {
-    netdata_thread_t thread;
+    ND_THREAD *thread;
     char path[FILENAME_MAX + 1];
     int disk_space_mb;
+    size_t retention_seconds;
     size_t tier;
     int ret;
 };
 
+typedef struct rrd_alert_prototype {
+    struct rrd_alert_match match;
+    struct rrd_alert_config config;
+
+    struct {
+        uint32_t uses;
+        bool enabled;
+        bool is_on_disk;
+        SPINLOCK spinlock;
+        struct rrd_alert_prototype *prev, *next;
+    } _internal;
+} RRD_ALERT_PROTOTYPE;
+
 void *dbengine_tier_init(void *ptr) {
     struct dbengine_initialization *dbi = ptr;
-    dbi->ret = rrdeng_init(NULL, dbi->path, dbi->disk_space_mb, dbi->tier);
+    dbi->ret = rrdeng_init(NULL, dbi->path, dbi->disk_space_mb, dbi->tier, dbi->retention_seconds);
     return ptr;
 }
+
+RRD_BACKFILL get_dbengine_backfill(RRD_BACKFILL backfill)
+{
+    const char *bf = config_get(
+        CONFIG_SECTION_DB,
+        "dbengine tier backfill",
+        backfill == RRD_BACKFILL_NEW  ? "new" :
+        backfill == RRD_BACKFILL_FULL ? "full" :
+                                        "none");
+
+    if (strcmp(bf, "new") == 0)
+        backfill = RRD_BACKFILL_NEW;
+    else if (strcmp(bf, "full") == 0)
+        backfill = RRD_BACKFILL_FULL;
+    else if (strcmp(bf, "none") == 0)
+        backfill = RRD_BACKFILL_NONE;
+    else {
+        nd_log(NDLS_DAEMON, NDLP_WARNING, "DBENGINE: unknown backfill value '%s', assuming 'new'", bf);
+        config_set(CONFIG_SECTION_DB, "dbengine tier backfill", "new");
+        backfill = RRD_BACKFILL_NEW;
+    }
+    return backfill;
+}
+
 #endif
 
 void dbengine_init(char *hostname) {
 #ifdef ENABLE_DBENGINE
+
     use_direct_io = config_get_boolean(CONFIG_SECTION_DB, "dbengine use direct io", use_direct_io);
 
-    unsigned read_num = (unsigned)config_get_number(CONFIG_SECTION_DB, "dbengine pages per extent", MAX_PAGES_PER_EXTENT);
-    if (read_num > 0 && read_num <= MAX_PAGES_PER_EXTENT)
+    unsigned read_num = (unsigned)config_get_number(CONFIG_SECTION_DB, "dbengine pages per extent", DEFAULT_PAGES_PER_EXTENT);
+    if (read_num > 0 && read_num <= DEFAULT_PAGES_PER_EXTENT)
         rrdeng_pages_per_extent = read_num;
     else {
         nd_log(NDLS_DAEMON, NDLP_WARNING,
@@ -853,8 +883,7 @@ void dbengine_init(char *hostname) {
 
     storage_tiers = config_get_number(CONFIG_SECTION_DB, "storage tiers", storage_tiers);
     if(storage_tiers < 1) {
-        nd_log(NDLS_DAEMON, NDLP_WARNING,
-               "At least 1 storage tier is required. Assuming 1.");
+        nd_log(NDLS_DAEMON, NDLP_WARNING, "At least 1 storage tier is required. Assuming 1.");
 
         storage_tiers = 1;
         config_set_number(CONFIG_SECTION_DB, "storage tiers", storage_tiers);
@@ -868,66 +897,54 @@ void dbengine_init(char *hostname) {
         config_set_number(CONFIG_SECTION_DB, "storage tiers", storage_tiers);
     }
 
+    new_dbengine_defaults =
+        (!legacy_multihost_db_space &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 1 update every iterations") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 2 update every iterations") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 3 update every iterations") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 4 update every iterations") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 1 disk space MB") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 2 disk space MB") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 3 disk space MB") &&
+         !config_exists(CONFIG_SECTION_DB, "dbengine tier 4 disk space MB"));
+
+    default_backfill = get_dbengine_backfill(RRD_BACKFILL_NEW);
+    char dbengineconfig[200 + 1];
+
+    size_t grouping_iterations = default_rrd_update_every;
+    storage_tiers_grouping_iterations[0] = default_rrd_update_every;
+
+    for (size_t tier = 1; tier < storage_tiers; tier++) {
+        grouping_iterations = storage_tiers_grouping_iterations[tier];
+        snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu update every iterations", tier);
+        grouping_iterations = config_get_number(CONFIG_SECTION_DB, dbengineconfig, grouping_iterations);
+        if(grouping_iterations < 2) {
+            grouping_iterations = 2;
+            config_set_number(CONFIG_SECTION_DB, dbengineconfig, grouping_iterations);
+            nd_log(NDLS_DAEMON, NDLP_WARNING,
+                   "DBENGINE on '%s': 'dbegnine tier %zu update every iterations' cannot be less than 2. Assuming 2.",
+                   hostname, tier);
+        }
+        storage_tiers_grouping_iterations[tier] = grouping_iterations;
+    }
+
+    default_multidb_disk_quota_mb = (int) config_get_number(CONFIG_SECTION_DB, "dbengine tier 0 disk space MB", RRDENG_DEFAULT_TIER_DISK_SPACE_MB);
+    if(default_multidb_disk_quota_mb && default_multidb_disk_quota_mb < RRDENG_MIN_DISK_SPACE_MB) {
+        netdata_log_error("Invalid disk space %d for tier 0 given. Defaulting to %d.", default_multidb_disk_quota_mb, RRDENG_MIN_DISK_SPACE_MB);
+        default_multidb_disk_quota_mb = RRDENG_MIN_DISK_SPACE_MB;
+        config_set_number(CONFIG_SECTION_DB, "dbengine tier 0 disk space MB", default_multidb_disk_quota_mb);
+    }
+
     bool parallel_initialization = (storage_tiers <= (size_t)get_netdata_cpus()) ? true : false;
-    parallel_initialization = config_get_boolean(CONFIG_SECTION_DB, "dbengine parallel initialization", parallel_initialization);
 
     struct dbengine_initialization tiers_init[RRD_STORAGE_TIERS] = {};
 
-    bool tiers_adjusted = false;
     size_t created_tiers = 0;
     char dbenginepath[FILENAME_MAX + 1];
-    char dbengineconfig[200 + 1];
-    int divisor = 1;
-    for(size_t tier = 0; tier < storage_tiers ;tier++) {
 
-        if(tier > 0)
-            divisor *= 2;
+    for (size_t tier = 0; tier < storage_tiers; tier++) {
 
-        int disk_space_mb = default_multidb_disk_quota_mb / divisor;
-        size_t grouping_iterations = storage_tiers_grouping_iterations[tier];
-        RRD_BACKFILL backfill = storage_tiers_backfill[tier];
-
-        if(tier > 0) {
-            snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu multihost disk space MB", tier);
-            disk_space_mb = config_get_number(CONFIG_SECTION_DB, dbengineconfig, disk_space_mb);
-
-            snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu update every iterations", tier);
-            grouping_iterations = config_get_number(CONFIG_SECTION_DB, dbengineconfig, grouping_iterations);
-            if(grouping_iterations < 2) {
-                grouping_iterations = 2;
-                config_set_number(CONFIG_SECTION_DB, dbengineconfig, grouping_iterations);
-                nd_log(NDLS_DAEMON, NDLP_WARNING,
-                       "DBENGINE on '%s': 'dbegnine tier %zu update every iterations' cannot be less than 2. Assuming 2.",
-                       hostname, tier);
-            }
-
-            snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu backfill", tier);
-            const char *bf = config_get(CONFIG_SECTION_DB, dbengineconfig, backfill == RRD_BACKFILL_NEW ? "new" : backfill == RRD_BACKFILL_FULL ? "full" : "none");
-            if(strcmp(bf, "new") == 0) backfill = RRD_BACKFILL_NEW;
-            else if(strcmp(bf, "full") == 0) backfill = RRD_BACKFILL_FULL;
-            else if(strcmp(bf, "none") == 0) backfill = RRD_BACKFILL_NONE;
-            else {
-                nd_log(NDLS_DAEMON, NDLP_WARNING, "DBENGINE: unknown backfill value '%s', assuming 'new'", bf);
-                config_set(CONFIG_SECTION_DB, dbengineconfig, "new");
-                backfill = RRD_BACKFILL_NEW;
-            }
-        }
-
-        storage_tiers_grouping_iterations[tier] = grouping_iterations;
-        storage_tiers_backfill[tier] = backfill;
-
-        if(tier > 0 && get_tier_grouping(tier) > 65535) {
-            storage_tiers_grouping_iterations[tier] = 1;
-            nd_log(NDLS_DAEMON, NDLP_WARNING,
-                   "DBENGINE on '%s': dbengine tier %zu gives aggregation of more than 65535 points of tier 0. "
-                   "Disabling tiers %zu and above",
-                   hostname, tier, tier);
-            storage_tiers = tier;
-            tiers_adjusted = true;
-            break;
-        }
-
-        if(tier == 0)
+        if (tier == 0)
             snprintfz(dbenginepath, FILENAME_MAX, "%s/dbengine", netdata_configured_cache_dir);
         else
             snprintfz(dbenginepath, FILENAME_MAX, "%s/dbengine-tier%zu", netdata_configured_cache_dir, tier);
@@ -935,33 +952,35 @@ void dbengine_init(char *hostname) {
         int ret = mkdir(dbenginepath, 0775);
         if (ret != 0 && errno != EEXIST) {
             nd_log(NDLS_DAEMON, NDLP_CRIT, "DBENGINE on '%s': cannot create directory '%s'", hostname, dbenginepath);
-            break;
+            continue;
         }
 
-        internal_error(true, "DBENGINE tier %zu grouping iterations is set to %zu", tier, storage_tiers_grouping_iterations[tier]);
+        int disk_space_mb = tier ? RRDENG_DEFAULT_TIER_DISK_SPACE_MB : default_multidb_disk_quota_mb;
+        snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu disk space MB", tier);
+        disk_space_mb = config_get_number(CONFIG_SECTION_DB, dbengineconfig, disk_space_mb);
 
-        tiers_init[tier].disk_space_mb = disk_space_mb;
+        snprintfz(dbengineconfig, sizeof(dbengineconfig) - 1, "dbengine tier %zu retention days", tier);
+        storage_tiers_retention_days[tier] = config_get_number(
+            CONFIG_SECTION_DB, dbengineconfig, new_dbengine_defaults ? storage_tiers_retention_days[tier] : 0);
+
+        tiers_init[tier].disk_space_mb = (int) disk_space_mb;
         tiers_init[tier].tier = tier;
+        tiers_init[tier].retention_seconds = (size_t) (86400.0 * storage_tiers_retention_days[tier]);
         strncpyz(tiers_init[tier].path, dbenginepath, FILENAME_MAX);
         tiers_init[tier].ret = 0;
 
         if(parallel_initialization) {
             char tag[NETDATA_THREAD_TAG_MAX + 1];
             snprintfz(tag, NETDATA_THREAD_TAG_MAX, "DBENGINIT[%zu]", tier);
-            netdata_thread_create(&tiers_init[tier].thread, tag, NETDATA_THREAD_OPTION_JOINABLE,
-                                  dbengine_tier_init, &tiers_init[tier]);
+            tiers_init[tier].thread = nd_thread_create(tag, NETDATA_THREAD_OPTION_JOINABLE, dbengine_tier_init, &tiers_init[tier]);
         }
         else
             dbengine_tier_init(&tiers_init[tier]);
     }
-    if (tiers_adjusted)
-        config_set_number(CONFIG_SECTION_DB, "storage tiers", storage_tiers);
 
     for(size_t tier = 0; tier < storage_tiers ;tier++) {
-        void *ptr;
-
         if(parallel_initialization)
-            netdata_thread_join(tiers_init[tier].thread, &ptr);
+            nd_thread_join(tiers_init[tier].thread);
 
         if(tiers_init[tier].ret != 0) {
             nd_log(NDLS_DAEMON, NDLP_ERR,
@@ -985,6 +1004,8 @@ void dbengine_init(char *hostname) {
     for(size_t tier = 0; tier < storage_tiers ;tier++)
         rrdeng_readiness_wait(multidb_ctx[tier]);
 
+    calculate_tier_disk_space_percentage();
+
     dbengine_enabled = true;
 #else
     storage_tiers = config_get_number(CONFIG_SECTION_DB, "storage tiers", 1);
@@ -1063,7 +1084,7 @@ int rrd_init(char *hostname, struct rrdhost_system_info *system_info, bool unitt
             , netdata_configured_abbrev_timezone
             , netdata_configured_utc_offset
             , program_name
-            , program_version
+            , NETDATA_VERSION
             , default_rrd_update_every
             , default_rrd_history_entries
             , default_rrd_memory_mode
@@ -1234,18 +1255,6 @@ void rrdhost_free___while_having_rrd_wrlock(RRDHOST *host, bool force) {
 
     rrdcalc_delete_all(host);
 
-    // ------------------------------------------------------------------------
-    // release its children resources
-
-#ifdef ENABLE_DBENGINE
-    for(size_t tier = 0; tier < storage_tiers ;tier++) {
-        if(host->db[tier].mode == RRD_MEMORY_MODE_DBENGINE
-            && host->db[tier].si
-            && !is_storage_engine_shared(host->db[tier].si))
-            rrdeng_prepare_exit((struct rrdengine_instance *)host->db[tier].si);
-    }
-#endif
-
     // delete all the RRDSETs of the host
     rrdset_index_destroy(host);
     rrdcalc_rrdhost_index_destroy(host);
@@ -1257,15 +1266,6 @@ void rrdhost_free___while_having_rrd_wrlock(RRDHOST *host, bool force) {
 
     health_alarm_log_free(host);
 
-#ifdef ENABLE_DBENGINE
-    for(size_t tier = 0; tier < storage_tiers ;tier++) {
-        if(host->db[tier].mode == RRD_MEMORY_MODE_DBENGINE
-            && host->db[tier].si
-            && !is_storage_engine_shared(host->db[tier].si))
-            rrdeng_exit((struct rrdengine_instance *)host->db[tier].si);
-    }
-#endif
-
     if (!netdata_exit && !force) {
         nd_log(NDLS_DAEMON, NDLP_DEBUG,
                "RRD: 'host:%s' is now in archive mode...",
@@ -1321,7 +1321,7 @@ void rrdhost_free_all(void) {
     if(localhost)
         rrdhost_free___while_having_rrd_wrlock(localhost, true);
 
-    rrd_unlock();
+    rrd_wrunlock();
 }
 
 void rrd_finalize_collection_for_all_hosts(void) {
